@@ -272,7 +272,6 @@ tile_surface (cairo_surface_t *surface,
 	}
 	else
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GtkStyleContext *context;
 		GdkRGBA bg;
 		context = gtk_style_context_new ();
@@ -282,11 +281,6 @@ tile_surface (cairo_surface_t *surface,
 		gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg);
 		gdk_cairo_set_source_rgba(cr, &bg);
 		g_object_unref (G_OBJECT (context));
-#else
-		GtkStyle *style;
-		style = gtk_widget_get_default_style ();
-		gdk_cairo_set_source_color(cr, &style->bg[GTK_STATE_NORMAL]);
-#endif
 	}
 
 	cairo_paint (cr);
@@ -302,48 +296,6 @@ tile_surface (cairo_surface_t *surface,
 	return copy;
 }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-static cairo_surface_t *
-tile_pixmap (GdkPixmap *pixmap,
-             int        width,
-             int        height)
-{
-	cairo_surface_t *copy;
-	cairo_t *cr;
-
-	copy = gdk_window_create_similar_surface (gdk_get_default_root_window (),
-	                                          CAIRO_CONTENT_COLOR,
-	                                          width, height);
-	cr = cairo_create (copy);
-
-	if (pixmap != NULL)
-	{
-		cairo_pattern_t *pattern;
-		gdk_cairo_set_source_pixmap (cr, pixmap, 0.0, 0.0);
-		pattern = cairo_get_source (cr);
-		cairo_pattern_set_extend (pattern, CAIRO_EXTEND_REPEAT);
-	}
-	else
-	{
-		GtkStyle *style;
-		style = gtk_widget_get_default_style ();
-		gdk_cairo_set_source_color (cr, &style->bg[GTK_STATE_NORMAL]);
-	}
-
-	cairo_paint (cr);
-
-	if (cairo_status (cr) != CAIRO_STATUS_SUCCESS)
-	{
-		cairo_surface_destroy (copy);
-		copy = NULL;
-	}
-
-	cairo_destroy(cr);
-
-	return copy;
-}
-#endif
-
 /**
  * mate_bg_crossfade_set_start_surface:
  * @fade: a #MateBGCrossfade
@@ -357,11 +309,7 @@ tile_pixmap (GdkPixmap *pixmap,
  * could not be copied.
  **/
 gboolean
-#if GTK_CHECK_VERSION(3, 0, 0)
 mate_bg_crossfade_set_start_surface (MateBGCrossfade* fade, cairo_surface_t *surface)
-#else
-mate_bg_crossfade_set_start_pixmap (MateBGCrossfade* fade, GdkPixmap *pixmap)
-#endif
 {
 	g_return_val_if_fail (MATE_IS_BG_CROSSFADE (fade), FALSE);
 
@@ -371,13 +319,9 @@ mate_bg_crossfade_set_start_pixmap (MateBGCrossfade* fade, GdkPixmap *pixmap)
 		fade->priv->start_surface = NULL;
 	}
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	fade->priv->start_surface = tile_surface (surface,
-#else
-	fade->priv->start_surface = tile_pixmap  (pixmap,
-#endif
-	                                          fade->priv->width,
-	                                          fade->priv->height);
+						  fade->priv->width,
+						  fade->priv->height);
 
 	return fade->priv->start_surface != NULL;
 }
@@ -410,11 +354,7 @@ get_current_time (void)
  * could not be copied.
  **/
 gboolean
-#if GTK_CHECK_VERSION(3, 0, 0)
 mate_bg_crossfade_set_end_surface (MateBGCrossfade* fade, cairo_surface_t *surface)
-#else
-mate_bg_crossfade_set_end_pixmap (MateBGCrossfade* fade, GdkPixmap *pixmap)
-#endif
 {
 	g_return_val_if_fail (MATE_IS_BG_CROSSFADE (fade), FALSE);
 
@@ -423,13 +363,9 @@ mate_bg_crossfade_set_end_pixmap (MateBGCrossfade* fade, GdkPixmap *pixmap)
 		fade->priv->end_surface = NULL;
 	}
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	fade->priv->end_surface = tile_surface (surface,
-#else
-	fade->priv->end_surface = tile_pixmap  (pixmap,
-#endif
-	                                        fade->priv->width,
-	                                        fade->priv->height);
+					        fade->priv->width,
+					        fade->priv->height);
 
 	/* Reset timer in case we're called while animating
 	 */
@@ -489,7 +425,7 @@ draw_background (MateBGCrossfade *fade)
 		cairo_paint (cr);
 		gdk_window_end_draw_frame (fade->priv->window, draw_context);
 		cairo_region_destroy (region);
-#elif GTK_CHECK_VERSION (3, 0, 0)
+#else
 		cairo_pattern_t *pattern;
 
 		pattern =
@@ -498,22 +434,6 @@ draw_background (MateBGCrossfade *fade)
 		cairo_pattern_destroy (pattern);
 		gdk_window_invalidate_rect (fade->priv->window, NULL, FALSE);
 		gdk_window_process_updates (fade->priv->window, FALSE);
-#else
-		cairo_t   *cr;
-		GdkPixmap *pixmap;
-
-		pixmap = gdk_pixmap_new (fade->priv->window,
-		                         fade->priv->width, fade->priv->height,
-		                         -1);
-		cr = gdk_cairo_create (pixmap);
-		cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-		cairo_set_source_surface (cr, fade->priv->fading_surface, 0, 0);
-		cairo_paint (cr);
-		cairo_destroy (cr);
-		gdk_window_set_back_pixmap (fade->priv->window, pixmap, FALSE);
-		g_object_unref (pixmap);
-		gdk_window_invalidate_rect (fade->priv->window, NULL, FALSE);
-		gdk_window_process_updates (fade->priv->window, FALSE);
 #endif
 	} else {
 		Display *xdisplay = GDK_WINDOW_XDISPLAY (fade->priv->window);
@@ -523,43 +443,21 @@ draw_background (MateBGCrossfade *fade)
 		send_root_property_change_notification (fade);
 		XFlush (xdisplay);
 		XUngrabServer (xdisplay);
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_error_trap_pop_ignored ();
-#else
-		gdk_error_trap_pop ();
-#endif
 	}
 }
 
 static gboolean
 on_widget_draw (GtkWidget       *widget,
-#if GTK_CHECK_VERSION (3, 0, 0)
                 cairo_t         *cr,
-#else
-                GdkEventExpose  *event,
-#endif
                 MateBGCrossfade *fade)
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	cairo_t *cr;
-
-#endif
 	g_assert (fade->priv->fading_surface != NULL);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	cr = gdk_cairo_create (event->window);
-
-	gdk_cairo_rectangle (cr, &event->area);
-	cairo_clip (cr);
-
-#endif
 	cairo_set_source_surface (cr, fade->priv->fading_surface, 0, 0);
 	cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
 	cairo_paint (cr);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	cairo_destroy (cr);
-#endif
 	return FALSE;
 }
 
@@ -711,11 +609,7 @@ get_root_pixmap_id_surface (GdkDisplay *display)
 			                                     w_ret, h_ret);
 		}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_error_trap_pop_ignored ();
-#else
-		gdk_error_trap_pop ();
-#endif
 		XFree (data);
 	}
 
@@ -737,7 +631,7 @@ get_root_pixmap_id_surface (GdkDisplay *display)
  **/
 void
 mate_bg_crossfade_start (MateBGCrossfade *fade,
-                         GdkWindow        *window)
+                         GdkWindow       *window)
 {
 	GSource *source;
 	GMainContext *context;
@@ -771,13 +665,8 @@ mate_bg_crossfade_start (MateBGCrossfade *fade,
 		                                           fade->priv->width,
 		                                           fade->priv->height);
 		if (fade->priv->widget != NULL) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_signal_connect (fade->priv->widget, "draw",
 			                  (GCallback) on_widget_draw, fade);
-#else
-			g_signal_connect (fade->priv->widget, "expose-event",
-			                  (GCallback) on_widget_draw, fade);
-#endif
 		}
 	} else {
 		cairo_t   *cr;
