@@ -47,9 +47,7 @@ Authors: Soren Sandmann <sandmann@redhat.com>
 #include <mate-bg.h>
 #include <mate-bg-crossfade.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 # include <cairo-xlib.h>
-#endif
 
 #define MATE_BG_CACHE_DIR "mate/background"
 
@@ -92,13 +90,8 @@ struct _MateBG {
 	char		*filename;
 	MateBGPlacement	 placement;
 	MateBGColorType	 color_type;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkRGBA	 	 primary;
 	GdkRGBA	 	 secondary;
-#else
-	GdkColor	 primary;
-	GdkColor	 secondary;
-#endif
 	gboolean	 is_enabled;
 
 	GFileMonitor* file_monitor;
@@ -130,21 +123,13 @@ static guint signals[N_SIGNALS] = {0};
 
 G_DEFINE_TYPE(MateBG, mate_bg, G_TYPE_OBJECT)
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static cairo_surface_t *make_root_pixmap     (GdkWindow  *window,
-#else
-static GdkPixmap       *make_root_pixmap     (GdkWindow  *window,
-#endif
                                               gint        width,
                                               gint        height);
 
 /* Pixbuf utils */
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void       pixbuf_average_value (GdkPixbuf  *pixbuf,
                                         GdkRGBA    *result);
-#else
-static guint32    pixbuf_average_value (GdkPixbuf  *pixbuf);
-#endif
 static GdkPixbuf *pixbuf_scale_to_fit  (GdkPixbuf  *src,
 					int         max_width,
 					int         max_height);
@@ -154,13 +139,8 @@ static GdkPixbuf *pixbuf_scale_to_min  (GdkPixbuf  *src,
 
 static void       pixbuf_draw_gradient (GdkPixbuf    *pixbuf,
 					gboolean      horizontal,
-#if GTK_CHECK_VERSION (3, 0, 0)
 					GdkRGBA     *c1,
 					GdkRGBA     *c2,
-#else
-					GdkColor     *c1,
-					GdkColor     *c2,
-#endif
 					GdkRectangle *rect);
 
 static void       pixbuf_tile          (GdkPixbuf  *src,
@@ -212,7 +192,6 @@ static FileSize   *find_best_size      (GSList                *sizes,
 					gint                   width,
 					gint                   height);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void
 color_from_string (const char *string,
 		   GdkRGBA   *colorp)
@@ -234,29 +213,6 @@ color_to_string (const GdkRGBA *color)
 				((guint) (color->green * 65535)) >> 8,
 				((guint) (color->blue * 65535)) >> 8);
 }
-#else
-static void
-color_from_string (const char *string,
-		   GdkColor   *colorp)
-{
-	/* If all else fails use black */
-	gdk_color_parse ("#000000", colorp);
-
-	if (!string)
-		return;
-
-	gdk_color_parse (string, colorp);
-}
-
-static char *
-color_to_string (const GdkColor *color)
-{
-	return g_strdup_printf ("#%02x%02x%02x",
-				color->red >> 8,
-				color->green >> 8,
-				color->blue >> 8);
-}
-#endif
 
 static gboolean
 do_changed (MateBG *bg)
@@ -375,11 +331,7 @@ mate_bg_load_from_gsettings (MateBG    *bg,
 	char    *tmp;
 	char    *filename;
 	MateBGColorType ctype;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkRGBA c1, c2;
-#else
-	GdkColor c1, c2;
-#endif
 	MateBGPlacement placement;
 
 	g_return_if_fail (MATE_IS_BG (bg));
@@ -567,26 +519,15 @@ mate_bg_new (void)
 void
 mate_bg_set_color (MateBG *bg,
 		    MateBGColorType type,
-#if GTK_CHECK_VERSION (3, 0, 0)
 		    GdkRGBA *primary,
 		    GdkRGBA *secondary)
-#else
-		    GdkColor *primary,
-		    GdkColor *secondary)
-#endif
 {
 	g_return_if_fail (bg != NULL);
 	g_return_if_fail (primary != NULL);
 
 	if (bg->color_type != type			||
-#if GTK_CHECK_VERSION (3, 0, 0)
 	    !gdk_rgba_equal (&bg->primary, primary)			||
 	    (secondary && !gdk_rgba_equal (&bg->secondary, secondary))) {
-#else
-	    !gdk_color_equal (&bg->primary, primary)			||
-	    (secondary && !gdk_color_equal (&bg->secondary, secondary))) {
-#endif
-
 		bg->color_type = type;
 		bg->primary = *primary;
 		if (secondary) {
@@ -621,13 +562,8 @@ mate_bg_get_placement (MateBG *bg)
 void
 mate_bg_get_color (MateBG		*bg,
 		   MateBGColorType	*type,
-#if GTK_CHECK_VERSION (3, 0, 0)
 		   GdkRGBA		*primary,
 		   GdkRGBA		*secondary)
-#else
-		   GdkColor		*primary,
-		   GdkColor		*secondary)
-#endif
 {
 	g_return_if_fail (bg != NULL);
 
@@ -869,15 +805,9 @@ draw_color_area (MateBG       *bg,
 	switch (bg->color_type) {
 	case MATE_BG_COLOR_SOLID:
 		/* not really a big deal to ignore the area of interest */
-#if GTK_CHECK_VERSION (3, 0, 0)
 		pixel = ((guint) (bg->primary.red * 0xff) << 24)   |
 			((guint) (bg->primary.green * 0xff) << 16) |
 			((guint) (bg->primary.blue * 0xff) << 8)   |
-#else
-		pixel = ((bg->primary.red >> 8) << 24)      |
-			((bg->primary.green >> 8) << 16)    |
-			((bg->primary.blue >> 8) << 8)      |
-#endif
 			(0xff);
 
 		gdk_pixbuf_fill (dest, pixel);
@@ -1196,13 +1126,8 @@ mate_bg_get_pixmap_size (MateBG   *bg,
  * so that if someone calls XKillClient on it, it won't affect the application
  * who created it.
  **/
-#if GTK_CHECK_VERSION (3, 0, 0)
 cairo_surface_t *
 mate_bg_create_surface (MateBG      *bg,
-#else
-GdkPixmap *
-mate_bg_create_pixmap  (MateBG      *bg,
-#endif
 		 	GdkWindow   *window,
 			int	     width,
 			int	     height,
@@ -1210,11 +1135,7 @@ mate_bg_create_pixmap  (MateBG      *bg,
 {
 	int pm_width, pm_height;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_surface_t *surface;
-#else
-	GdkPixmap *pixmap;
-#endif
 	cairo_t *cr;
 
 	g_return_val_if_fail (bg != NULL, NULL);
@@ -1233,33 +1154,17 @@ mate_bg_create_pixmap  (MateBG      *bg,
 
 	if (root)
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		surface = make_root_pixmap (window, pm_width, pm_height);
-#else
-		pixmap = make_root_pixmap (window, pm_width, pm_height);
-#endif
 	}
 	else
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		surface = gdk_window_create_similar_surface (window, CAIRO_CONTENT_COLOR,
 							     pm_width, pm_height);
-#else
-		pixmap = gdk_pixmap_new (window, pm_width, pm_height, -1);
-#endif
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cr = cairo_create (surface);
-#else
-	cr = gdk_cairo_create (pixmap);
-#endif
 	if (!bg->filename && bg->color_type == MATE_BG_COLOR_SOLID) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_cairo_set_source_rgba (cr, &(bg->primary));
-#else
-		gdk_cairo_set_source_color (cr, &(bg->primary));
-#endif
 	}
 	else
 	{
@@ -1276,11 +1181,7 @@ mate_bg_create_pixmap  (MateBG      *bg,
 
 	cairo_destroy (cr);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	return surface;
-#else
-	return pixmap;
-#endif
 }
 
 
@@ -1292,11 +1193,7 @@ mate_bg_is_dark (MateBG *bg,
 		  int      width,
 		  int      height)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkRGBA color;
-#else
-	GdkColor color;
-#endif
 	int intensity;
 	GdkPixbuf *pixbuf;
 
@@ -1311,7 +1208,6 @@ mate_bg_is_dark (MateBG *bg,
 	}
 	pixbuf = get_pixbuf_for_size (bg, -1, width, height);
 	if (pixbuf) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GdkRGBA argb;
 		guchar a, r, g, b;
 
@@ -1320,13 +1216,6 @@ mate_bg_is_dark (MateBG *bg,
 		r = argb.red * 0xff;
 		g = argb.green * 0xff;
 		b = argb.blue * 0xff;
-#else
-		guint32 argb = pixbuf_average_value (pixbuf);
-		guchar a = (argb >> 24) & 0xff;
-		guchar r = (argb >> 16) & 0xff;
-		guchar g = (argb >>  8) & 0xff;
-		guchar b = (argb >>  0) & 0xff;
-#endif
 
 		color.red = (color.red * (0xFF - a) + r * 0x101 * a) / 0xFF;
 		color.green = (color.green * (0xFF - a) + g * 0x101 * a) / 0xFF;
@@ -1334,15 +1223,9 @@ mate_bg_is_dark (MateBG *bg,
 		g_object_unref (pixbuf);
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	intensity = ((guint) (color.red * 65535) * 77 +
 		     (guint) (color.green * 65535) * 150 +
 		     (guint) (color.blue * 65535) * 28) >> 16;
-#else
-	intensity = (color.red * 77 +
-		     color.green * 150 +
-		     color.blue * 28) >> 16;
-#endif
 
 	return intensity < 160; /* biased slightly to be dark */
 }
@@ -1351,22 +1234,14 @@ mate_bg_is_dark (MateBG *bg,
  * Create a persistent pixmap. We create a separate display
  * and set the closedown mode on it to RetainPermanent.
  */
-#if GTK_CHECK_VERSION (3, 0, 0)
 static cairo_surface_t *
-#else
-static GdkPixmap *
-#endif
 make_root_pixmap (GdkWindow *window, gint width, gint height)
 {
 	GdkScreen *screen = gdk_window_get_screen(window);
 	char *disp_name = DisplayString (GDK_WINDOW_XDISPLAY (window));
 	Display *display;
 	Pixmap xpixmap;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_surface_t *surface;
-#else
-	GdkPixmap *pixmap;
-#endif
 	int depth;
 
 	/* Desktop background pixmap should be created from dummy X client since most
@@ -1387,18 +1262,11 @@ make_root_pixmap (GdkWindow *window, gint width, gint height)
 	XSetCloseDownMode (display, RetainPermanent);
 	XCloseDisplay (display);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	surface = cairo_xlib_surface_create (GDK_SCREEN_XDISPLAY (screen), xpixmap,
                                              GDK_VISUAL_XVISUAL (gdk_screen_get_system_visual (screen)),
         				     width, height);
 
 	return surface;
-#else
-	pixmap = gdk_pixmap_foreign_new_for_screen (screen, xpixmap, width, height, depth);
-	gdk_drawable_set_colormap (pixmap, gdk_drawable_get_colormap (window));
-
-	return pixmap;
-#endif
 }
 
 static gboolean
@@ -1524,13 +1392,8 @@ mate_bg_create_thumbnail (MateBG               *bg,
  *
  * Return value: a #cairo_surface_t if successful or %NULL
  **/
-#if GTK_CHECK_VERSION (3, 0, 0)
 cairo_surface_t *
 mate_bg_get_surface_from_root (GdkScreen *screen)
-#else
-GdkPixmap *
-mate_bg_get_pixmap_from_root (GdkScreen *screen)
-#endif
 {
 	int result;
 	gint format;
@@ -1540,13 +1403,8 @@ mate_bg_get_pixmap_from_root (GdkScreen *screen)
 	Atom type;
 	Display *display;
 	int screen_num;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_surface_t *surface;
 	cairo_surface_t *source_pixmap;
-#else
-	GdkPixmap *pixmap;
-	GdkPixmap *source_pixmap;
-#endif
 	int width, height;
 	cairo_t *cr;
 
@@ -1559,11 +1417,7 @@ mate_bg_get_pixmap_from_root (GdkScreen *screen)
 				     0L, 1L, False, XA_PIXMAP,
 				     &type, &format, &nitems, &bytes_after,
 				     &data);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	surface = NULL;
-#else
-	pixmap = NULL;
-#endif
 	source_pixmap = NULL;
 
 	if (result != Success || type != XA_PIXMAP ||
@@ -1573,14 +1427,13 @@ mate_bg_get_pixmap_from_root (GdkScreen *screen)
 	}
 
 	if (data != NULL) {
-#  if GTK_CHECK_VERSION (3, 0, 0)
+		gdk_error_trap_push ();
+
 		Pixmap xpixmap = *(Pixmap *) data;
 		Window root_return;
 		int x_ret, y_ret;
 		unsigned int w_ret, h_ret, bw_ret, depth_ret;
 
-		gdk_error_trap_push ();
-
 		if (XGetGeometry (GDK_SCREEN_XDISPLAY (screen),
 				  xpixmap,
 				  &root_return,
@@ -1593,22 +1446,11 @@ mate_bg_get_pixmap_from_root (GdkScreen *screen)
 		}
 
 		gdk_error_trap_pop_ignored ();
-#  else
-		gdk_error_trap_push ();
-		source_pixmap = gdk_pixmap_foreign_new (*(Pixmap *) data);
-		gdk_error_trap_pop ();
-
-		if (source_pixmap != NULL) {
-			gdk_drawable_set_colormap (source_pixmap,
-						   gdk_screen_get_default_colormap (screen));
-		}
-#  endif
 	}
 
 	width = gdk_screen_get_width (screen);
 	height = gdk_screen_get_height (screen);
 
-#  if GTK_CHECK_VERSION (3, 0, 0)
 	if (source_pixmap) {
 		surface = cairo_surface_create_similar (source_pixmap,
 							CAIRO_CONTENT_COLOR,
@@ -1634,40 +1476,11 @@ mate_bg_get_pixmap_from_root (GdkScreen *screen)
 
 	if (source_pixmap != NULL)
 		cairo_surface_destroy (source_pixmap);
-#  else
-	pixmap = gdk_pixmap_new (source_pixmap != NULL? source_pixmap :
-				 gdk_screen_get_root_window (screen),
-				 width, height, -1);
-
-	cr = gdk_cairo_create (pixmap);
-	if (source_pixmap != NULL) {
-		cairo_pattern_t *pattern;
-		gdk_cairo_set_source_pixmap (cr, source_pixmap, 0, 0);
-		pattern = cairo_get_source (cr);
-		cairo_pattern_set_extend (pattern, CAIRO_EXTEND_REPEAT);
-	} else {
-		cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
-	}
-	cairo_paint (cr);
-
-	if (cairo_status (cr) != CAIRO_STATUS_SUCCESS) {
-		g_object_unref (pixmap);
-		pixmap = NULL;
-	}
-	cairo_destroy (cr);
-
-	if (source_pixmap != NULL)
-		g_object_unref (source_pixmap);
-#  endif
 
 	if (data != NULL)
 		XFree (data);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	return surface;
-#else
-	return pixmap;
-#endif
 }
 
 /* Sets the "ESETROOT_PMAP_ID" property to later be used to free the pixmap,
@@ -1716,12 +1529,7 @@ mate_bg_set_root_pixmap_id (GdkScreen       *screen,
 				if (esetrootpmap && esetrootpmap != xrootpmap) {
 					XKillClient (display, esetrootpmap);
 				}
-#if GTK_CHECK_VERSION (3, 0, 0)
 				gdk_error_trap_pop_ignored ();
-#else
-				XSync (display, False);
-				gdk_error_trap_pop ();
-#endif
 			}
 			if (data_esetroot != NULL) {
 				XFree (data_esetroot);
@@ -1763,28 +1571,16 @@ mate_bg_set_root_pixmap_id (GdkScreen       *screen,
  * to mate_bg_create_surface().
  **/
 void
-#if GTK_CHECK_VERSION (3, 0, 0)
 mate_bg_set_surface_as_root (GdkScreen *screen, cairo_surface_t *surface)
-#else
-mate_bg_set_pixmap_as_root  (GdkScreen *screen, GdkPixmap *pixmap)
-#endif
 {
 	g_return_if_fail (screen != NULL);
-#  if GTK_CHECK_VERSION (3, 0, 0)
 	g_return_if_fail (cairo_surface_get_type (surface) == CAIRO_SURFACE_TYPE_XLIB);
-#  else
-	g_return_if_fail (pixmap != NULL);
-#  endif
 
 	/* Desktop background pixmap should be created from dummy X client since most
 	 * applications will try to kill it with XKillClient later when changing pixmap
 	 */
 	Display    *display      = GDK_DISPLAY_XDISPLAY (gdk_screen_get_display (screen));
-#if GTK_CHECK_VERSION (3, 0, 0)
 	Pixmap      pixmap_id    = cairo_xlib_surface_get_drawable (surface);
-#else
-	Pixmap      pixmap_id    = GDK_DRAWABLE_XID (pixmap);
-#endif
 	Window      xroot        = RootWindow (display, gdk_screen_get_number (screen));
 
 	XGrabServer (display);
@@ -1810,70 +1606,39 @@ mate_bg_set_pixmap_as_root  (GdkScreen *screen, GdkPixmap *pixmap)
  * Return value: (transfer full): a #MateBGCrossfade object
  **/
 MateBGCrossfade *
-#if GTK_CHECK_VERSION (3, 0, 0)
 mate_bg_set_surface_as_root_with_crossfade (GdkScreen       *screen,
 		 			    cairo_surface_t *surface)
-#else
-mate_bg_set_pixmap_as_root_with_crossfade (GdkScreen *screen,
-		 			   GdkPixmap *pixmap)
-#endif
 {
 	GdkWindow       *root_window;
 	int              width, height;
 	MateBGCrossfade *fade;
 	cairo_t         *cr;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_surface_t *old_surface;
-#else
-	GdkPixmap       *old_pixmap;
-#endif
 
 	g_return_val_if_fail (screen != NULL, NULL);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_return_val_if_fail (surface != NULL, NULL);
-#else
-	g_return_val_if_fail (pixmap != NULL, NULL);
-#endif
 
 	root_window = gdk_screen_get_root_window (screen);
 	width       = gdk_window_get_width (root_window);
 	height      = gdk_window_get_height (root_window);
 	fade        = mate_bg_crossfade_new (width, height);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	old_surface = mate_bg_get_surface_from_root (screen);
 
 	mate_bg_crossfade_set_start_surface (fade, old_surface);
 	mate_bg_crossfade_set_end_surface (fade, surface);
-#else
-	old_pixmap = mate_bg_get_pixmap_from_root (screen);
-
-	mate_bg_crossfade_set_start_pixmap (fade, old_pixmap);
-	mate_bg_crossfade_set_end_pixmap (fade, pixmap);
-#endif
 
 	/* Before setting the surface as a root pixmap, let's have it draw
 	 * the old stuff, just so it won't be noticable
 	 * (crossfade will later get it back)
 	 */
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cr = cairo_create (surface);
 	cairo_set_source_surface (cr, old_surface, 0, 0);
-#else
-	cr = gdk_cairo_create (pixmap);
-	gdk_cairo_set_source_pixmap (cr, old_pixmap, 0, 0);
-#endif
 	cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
 	cairo_paint (cr);
 	cairo_destroy (cr);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_surface_destroy (old_surface);
 
 	mate_bg_set_surface_as_root (screen, surface);
-#else
-	g_object_unref (old_pixmap);
-
-	mate_bg_set_pixmap_as_root (screen, pixmap);
-#endif
 	mate_bg_crossfade_start (fade, root_window);
 
 	return fade;
@@ -2656,14 +2421,9 @@ clear_cache (MateBG *bg)
 }
 
 /* Pixbuf utilities */
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void
 pixbuf_average_value (GdkPixbuf *pixbuf,
                       GdkRGBA   *result)
-#else
-static guint32
-pixbuf_average_value (GdkPixbuf *pixbuf)
-#endif
 {
 	guint64 a_total, r_total, g_total, b_total;
 	guint row, column;
@@ -2672,9 +2432,7 @@ pixbuf_average_value (GdkPixbuf *pixbuf)
 	int r, g, b, a;
 	guint64 dividend;
 	guint width, height;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gdouble dd;
-#endif
 
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
@@ -2720,20 +2478,12 @@ pixbuf_average_value (GdkPixbuf *pixbuf)
 		dividend = height * width;
 		a_total = dividend * 0xFF;
 	}
-#if GTK_CHECK_VERSION (3, 0, 0)
 
 	dd = dividend * 0xFF;
 	result->alpha = a_total / dd;
 	result->red = r_total / dd;
 	result->green = g_total / dd;
 	result->blue = b_total / dd;
-#else
-
-	return ((a_total + dividend / 2) / dividend) << 24
-		| ((r_total + dividend / 2) / dividend) << 16
-		| ((g_total + dividend / 2) / dividend) << 8
-		| ((b_total + dividend / 2) / dividend);
-#endif
 }
 
 static GdkPixbuf *
@@ -2789,13 +2539,8 @@ pixbuf_scale_to_min (GdkPixbuf *src, int min_width, int min_height)
 }
 
 static guchar *
-#if GTK_CHECK_VERSION (3, 0, 0)
 create_gradient (const GdkRGBA *primary,
 		 const GdkRGBA *secondary,
-#else
-create_gradient (const GdkColor *primary,
-		 const GdkColor *secondary,
-#endif
 		 int	         n_pixels)
 {
 	guchar *result = g_malloc (n_pixels * 3);
@@ -2804,15 +2549,9 @@ create_gradient (const GdkColor *primary,
 	for (i = 0; i < n_pixels; ++i) {
 		double ratio = (i + 0.5) / n_pixels;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		result[3 * i + 0] = (guchar) ((primary->red * (1 - ratio) + secondary->red * ratio) * 0x100);
 		result[3 * i + 1] = (guchar) ((primary->green * (1 - ratio) + secondary->green * ratio) * 0x100);
 		result[3 * i + 2] = (guchar) ((primary->blue * (1 - ratio) + secondary->blue * ratio) * 0x100);
-#else
-		result[3 * i + 0] = ((guint16) (primary->red * (1 - ratio) + secondary->red * ratio)) >> 8;
-		result[3 * i + 1] = ((guint16) (primary->green * (1 - ratio) + secondary->green * ratio)) >> 8;
-		result[3 * i + 2] = ((guint16) (primary->blue * (1 - ratio) + secondary->blue * ratio)) >> 8;
-#endif
 	}
 
 	return result;
@@ -2821,13 +2560,8 @@ create_gradient (const GdkColor *primary,
 static void
 pixbuf_draw_gradient (GdkPixbuf    *pixbuf,
 		      gboolean      horizontal,
-#if GTK_CHECK_VERSION (3, 0, 0)
 		      GdkRGBA      *primary,
 		      GdkRGBA      *secondary,
-#else
-		      GdkColor     *primary,
-		      GdkColor     *secondary,
-#endif
 		      GdkRectangle *rect)
 {
 	int width;
