@@ -35,13 +35,6 @@
 #include <glib/gi18n-lib.h>
 #include "mate-colorsel.h"
 
-#if !GTK_CHECK_VERSION(3,0,0)
-#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
-# define gtk_separator_new(orientation) \
-  (((orientation) == GTK_ORIENTATION_HORIZONTAL) ? \
-    gtk_hseparator_new () : gtk_vseparator_new ())
-#endif
-
 #define DEFAULT_COLOR_PALETTE "#ef2929:#fcaf3e:#fce94f:#8ae234:#729fcf:#ad7fa8:#e9b96e:#888a85:#eeeeec:#cc0000:#f57900:#edd400:#73d216:#3465a4:#75507b:#c17d11:#555753:#d3d7cf:#a40000:#ce5c00:#c4a000:#4e9a06:#204a87:#5c3566:#8f5902:#2e3436:#babdb6:#000000:#2e3436:#555753:#888a85:#babdb6:#d3d7cf:#eeeeec:#f3f3f3:#ffffff"
 
 /* Number of elements in the custom palatte */
@@ -188,13 +181,13 @@ static void 	color_sample_new                        (MateColorSelection *colors
 static void 	make_label_spinbutton     		(MateColorSelection *colorsel,
 	    				  		 GtkWidget        **spinbutton,
 	    				  		 gchar             *text,
-	    				  		 GtkWidget         *table,
+	    				  		 GtkWidget         *grid,
 	    				  		 gint               i,
 	    				  		 gint               j,
 	    				  		 gint               channel_type,
 	    				  		 const gchar       *tooltip);
 static void 	make_palette_frame                      (MateColorSelection *colorsel,
-							 GtkWidget         *table,
+							 GtkWidget         *grid,
 							 gint               i,
 							 gint               j);
 static void 	set_selected_palette                    (MateColorSelection *colorsel,
@@ -217,7 +210,6 @@ static guint color_selection_signals[LAST_SIGNAL] = { 0 };
 static MateColorSelectionChangePaletteFunc noscreen_change_palette_hook = default_noscreen_change_palette_func;
 static MateColorSelectionChangePaletteWithScreenFunc change_palette_hook = default_change_palette_func;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static const guchar dropper_bits[] = {
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377"
@@ -260,29 +252,6 @@ static const guchar dropper_bits[] = {
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
-#else
-static const guchar dropper_bits[] = {
-  0xff, 0x8f, 0x01, 0x00,  0xff, 0x77, 0x01, 0x00,
-  0xff, 0xfb, 0x00, 0x00,  0xff, 0xf8, 0x00, 0x00,
-  0x7f, 0xff, 0x00, 0x00,  0xff, 0x7e, 0x01, 0x00,
-  0xff, 0x9d, 0x01, 0x00,  0xff, 0xd8, 0x01, 0x00,
-  0x7f, 0xd4, 0x01, 0x00,  0x3f, 0xee, 0x01, 0x00,
-  0x1f, 0xff, 0x01, 0x00,  0x8f, 0xff, 0x01, 0x00,
-  0xc7, 0xff, 0x01, 0x00,  0xe3, 0xff, 0x01, 0x00,
-  0xf3, 0xff, 0x01, 0x00,  0xfd, 0xff, 0x01, 0x00,
-  0xff, 0xff, 0x01, 0x00 };
-
-static const guchar dropper_mask[] = {
-  0x00, 0x70, 0x00, 0x00,  0x00, 0xf8, 0x00, 0x00,
-  0x00, 0xfc, 0x01, 0x00,  0x00, 0xff, 0x01, 0x00,
-  0x80, 0xff, 0x01, 0x00,  0x00, 0xff, 0x00, 0x00,
-  0x00, 0x7f, 0x00, 0x00,  0x80, 0x3f, 0x00, 0x00,
-  0xc0, 0x3f, 0x00, 0x00,  0xe0, 0x13, 0x00, 0x00,
-  0xf0, 0x01, 0x00, 0x00,  0xf8, 0x00, 0x00, 0x00,
-  0x7c, 0x00, 0x00, 0x00,  0x3e, 0x00, 0x00, 0x00,
-  0x1e, 0x00, 0x00, 0x00,  0x0d, 0x00, 0x00, 0x00,
-  0x02, 0x00, 0x00, 0x00 };
-#endif
 
 G_DEFINE_TYPE (MateColorSelection, mate_color_selection, GTK_TYPE_BOX)
 
@@ -359,7 +328,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
 {
   GtkWidget *top_hbox;
   GtkWidget *top_right_vbox;
-  GtkWidget *table, *label, *hbox, *frame, *vbox, *button;
+  GtkWidget *grid, *label, *hbox, *frame, *vbox, *button;
   GtkAdjustment *adjust;
   GtkWidget *picker_image;
   gint i, j;
@@ -369,27 +338,15 @@ mate_color_selection_init (MateColorSelection *colorsel)
   
   _mate_desktop_init_i18n ();
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_widget_push_composite_child ();
-#endif
-
   priv = colorsel->private_data = G_TYPE_INSTANCE_GET_PRIVATE (colorsel, MATE_TYPE_COLOR_SELECTION, ColorSelectionPrivate);
   priv->changing = FALSE;
   priv->default_set = FALSE;
   priv->default_alpha_set = FALSE;
   
-#if GTK_CHECK_VERSION (3, 0, 0)
   top_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-#else
-  top_hbox = gtk_hbox_new (FALSE, 12);
-#endif
   gtk_box_pack_start (GTK_BOX (colorsel), top_hbox, FALSE, FALSE, 0);
   
-#if GTK_CHECK_VERSION (3, 0, 0)
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-  vbox = gtk_vbox_new (FALSE, 6);
-#endif
   priv->triangle_colorsel = gtk_hsv_new ();
   g_signal_connect (priv->triangle_colorsel, "changed",
                     G_CALLBACK (hsv_changed), colorsel);
@@ -399,11 +356,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
   gtk_widget_set_tooltip_text (priv->triangle_colorsel,
                         _("Select the color you want from the outer ring. Select the darkness or lightness of that color using the inner triangle."));
   
-#if GTK_CHECK_VERSION (3, 0, 0)
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-#else
-  hbox = gtk_hbox_new (FALSE, 6);
-#endif
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   
   frame = gtk_frame_new (NULL);
@@ -427,31 +380,27 @@ mate_color_selection_init (MateColorSelection *colorsel)
   gtk_widget_set_tooltip_text (button,
                         _("Click the eyedropper, then click a color anywhere on your screen to select that color."));
   
-#if GTK_CHECK_VERSION (3, 0, 0)
   top_right_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-  top_right_vbox = gtk_vbox_new (FALSE, 6);
-#endif
   gtk_box_pack_start (GTK_BOX (top_hbox), top_right_vbox, FALSE, FALSE, 0);
-  table = gtk_table_new (8, 6, FALSE);
-  gtk_box_pack_start (GTK_BOX (top_right_vbox), table, FALSE, FALSE, 0);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+  grid = gtk_grid_new ();
+  gtk_box_pack_start (GTK_BOX (top_right_vbox), grid, FALSE, FALSE, 0);
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
   
-  make_label_spinbutton (colorsel, &priv->hue_spinbutton, _("_Hue:"), table, 0, 0, COLORSEL_HUE,
+  make_label_spinbutton (colorsel, &priv->hue_spinbutton, _("_Hue:"), grid, 0, 0, COLORSEL_HUE,
                          _("Position on the color wheel."));
   gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (priv->hue_spinbutton), TRUE);
-  make_label_spinbutton (colorsel, &priv->sat_spinbutton, _("_Saturation:"), table, 0, 1, COLORSEL_SATURATION,
+  make_label_spinbutton (colorsel, &priv->sat_spinbutton, _("_Saturation:"), grid, 0, 1, COLORSEL_SATURATION,
                          _("\"Deepness\" of the color."));
-  make_label_spinbutton (colorsel, &priv->val_spinbutton, _("_Value:"), table, 0, 2, COLORSEL_VALUE,
+  make_label_spinbutton (colorsel, &priv->val_spinbutton, _("_Value:"), grid, 0, 2, COLORSEL_VALUE,
                          _("Brightness of the color."));
-  make_label_spinbutton (colorsel, &priv->red_spinbutton, _("_Red:"), table, 6, 0, COLORSEL_RED,
+  make_label_spinbutton (colorsel, &priv->red_spinbutton, _("_Red:"), grid, 6, 0, COLORSEL_RED,
                          _("Amount of red light in the color."));
-  make_label_spinbutton (colorsel, &priv->green_spinbutton, _("_Green:"), table, 6, 1, COLORSEL_GREEN,
+  make_label_spinbutton (colorsel, &priv->green_spinbutton, _("_Green:"), grid, 6, 1, COLORSEL_GREEN,
                          _("Amount of green light in the color."));
-  make_label_spinbutton (colorsel, &priv->blue_spinbutton, _("_Blue:"), table, 6, 2, COLORSEL_BLUE,
+  make_label_spinbutton (colorsel, &priv->blue_spinbutton, _("_Blue:"), grid, 6, 2, COLORSEL_BLUE,
                          _("Amount of blue light in the color."));
-  gtk_table_attach_defaults (GTK_TABLE (table), gtk_separator_new (GTK_ORIENTATION_HORIZONTAL), 0, 8, 3, 4); 
+  gtk_grid_attach (GTK_GRID (grid), gtk_separator_new (GTK_ORIENTATION_HORIZONTAL), 0, 3, 8, 1); 
 
   priv->opacity_label = gtk_label_new_with_mnemonic (_("Op_acity:"));
 #if GTK_CHECK_VERSION (3, 16, 0)
@@ -459,7 +408,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
 #else
   gtk_misc_set_alignment (GTK_MISC (priv->opacity_label), 0.0, 0.5);
 #endif
-  gtk_table_attach_defaults (GTK_TABLE (table), priv->opacity_label, 0, 1, 4, 5); 
+  gtk_grid_attach (GTK_GRID (grid), priv->opacity_label, 0, 4, 1, 1); 
   adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 255.0, 1.0, 1.0, 0.0)); 
   g_object_set_data (G_OBJECT (adjust), "COLORSEL", colorsel); 
   priv->opacity_slider = gtk_hscale_new (adjust);
@@ -471,7 +420,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
   g_signal_connect (adjust, "value-changed",
                     G_CALLBACK (adjustment_changed),
                     GINT_TO_POINTER (COLORSEL_OPACITY));
-  gtk_table_attach_defaults (GTK_TABLE (table), priv->opacity_slider, 1, 7, 4, 5); 
+  gtk_grid_attach (GTK_GRID (grid), priv->opacity_slider, 1, 4, 6, 1); 
   priv->opacity_entry = gtk_entry_new (); 
   gtk_widget_set_tooltip_text (priv->opacity_entry,
                         _("Transparency of the color."));
@@ -479,10 +428,10 @@ mate_color_selection_init (MateColorSelection *colorsel)
 
   g_signal_connect (priv->opacity_entry, "activate",
                     G_CALLBACK (opacity_entry_changed), colorsel);
-  gtk_table_attach_defaults (GTK_TABLE (table), priv->opacity_entry, 7, 8, 4, 5);
+  gtk_grid_attach (GTK_GRID (grid), priv->opacity_entry, 7, 4, 1, 1);
   
   label = gtk_label_new_with_mnemonic (_("Color _name:"));
-  gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 5, 6);
+  gtk_grid_attach (GTK_GRID (grid), label, 0, 5, 1, 1);
 #if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 #else
@@ -502,7 +451,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
                         _("You can enter an HTML-style hexadecimal color value, or simply a color name such as 'orange' in this entry."));
   
   gtk_entry_set_width_chars (GTK_ENTRY (priv->hex_entry), 7);
-  gtk_table_attach_defaults (GTK_TABLE (table), priv->hex_entry, 1, 5, 5, 6);
+  gtk_grid_attach (GTK_GRID (grid), priv->hex_entry, 1, 5, 4, 1);
 
   focus_chain = g_list_append (focus_chain, priv->hue_spinbutton);
   focus_chain = g_list_append (focus_chain, priv->sat_spinbutton);
@@ -513,26 +462,22 @@ mate_color_selection_init (MateColorSelection *colorsel)
   focus_chain = g_list_append (focus_chain, priv->opacity_slider);
   focus_chain = g_list_append (focus_chain, priv->opacity_entry);
   focus_chain = g_list_append (focus_chain, priv->hex_entry);
-  gtk_container_set_focus_chain (GTK_CONTAINER (table), focus_chain);
+  gtk_container_set_focus_chain (GTK_CONTAINER (grid), focus_chain);
   g_list_free (focus_chain);
 
   /* Set up the palette */
-  table = gtk_table_new (GTK_CUSTOM_PALETTE_HEIGHT, GTK_CUSTOM_PALETTE_WIDTH, TRUE);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 1);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 1);
+  grid = gtk_grid_new ();
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 1);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 1);
   for (i = 0; i < GTK_CUSTOM_PALETTE_WIDTH; i++)
     {
       for (j = 0; j < GTK_CUSTOM_PALETTE_HEIGHT; j++)
 	{
-	  make_palette_frame (colorsel, table, i, j);
+	  make_palette_frame (colorsel, grid, i, j);
 	}
     }
   set_selected_palette (colorsel, 0, 0);
-#if GTK_CHECK_VERSION (3, 0, 0)
   priv->palette_frame = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-  priv->palette_frame = gtk_vbox_new (FALSE, 6);
-#endif
   label = gtk_label_new_with_mnemonic (_("_Palette:"));
 #if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
@@ -545,7 +490,7 @@ mate_color_selection_init (MateColorSelection *colorsel)
                                  priv->custom_palette[0][0]);
   
   gtk_box_pack_end (GTK_BOX (top_right_vbox), priv->palette_frame, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (priv->palette_frame), table, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (priv->palette_frame), grid, FALSE, FALSE, 0);
   
   gtk_widget_show_all (top_hbox);
 
@@ -570,10 +515,6 @@ mate_color_selection_init (MateColorSelection *colorsel)
       atk_object_set_role (gtk_widget_get_accessible (GTK_WIDGET (colorsel)), ATK_ROLE_COLOR_CHOOSER);
       make_all_relations (atk_obj, priv);
     } 
-
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_widget_pop_composite_child ();
-#endif
 }
 
 /* GObject methods */
@@ -718,11 +659,7 @@ mate_color_selection_grab_broken (GtkWidget          *widget,
  *
  */
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void color_sample_draw_sample (MateColorSelection *colorsel, cairo_t *cr, int which);
-#else
-static void color_sample_draw_sample (MateColorSelection *colorsel, int which);
-#endif
 static void color_sample_update_samples (MateColorSelection *colorsel);
 
 static void
@@ -881,18 +818,11 @@ color_sample_drag_handle (GtkWidget        *widget,
 
 /* which = 0 means draw old sample, which = 1 means draw new */
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 color_sample_draw_sample (MateColorSelection *colorsel, cairo_t *cr, int which)
-#else
-color_sample_draw_sample (MateColorSelection *colorsel, int which)
-#endif
 {
   GtkWidget *da;
   gint x, y, wid, heig, goff;
   ColorSelectionPrivate *priv;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cairo_t *cr;
-#endif
   GtkAllocation allocation;
   
   g_return_if_fail (colorsel != NULL);
@@ -914,10 +844,6 @@ color_sample_draw_sample (MateColorSelection *colorsel, int which)
       goff =  allocation.width % 32;
     }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cr = gdk_cairo_create (gtk_widget_get_window (da));
-#endif
-  
   gtk_widget_get_allocation (da, &allocation);
   wid = allocation.width;
   heig = allocation.height;
@@ -961,10 +887,6 @@ color_sample_draw_sample (MateColorSelection *colorsel, int which)
 
   cairo_rectangle (cr, 0, 0, wid, heig);
   cairo_fill (cr);
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cairo_destroy (cr);
-#endif
 }
 
 
@@ -976,7 +898,6 @@ color_sample_update_samples (MateColorSelection *colorsel)
   gtk_widget_queue_draw (priv->cur_sample);
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean
 color_old_sample_draw (GtkWidget          *da,
                        cairo_t            *cr,
@@ -995,26 +916,6 @@ color_cur_sample_draw (GtkWidget          *da,
   color_sample_draw_sample (colorsel, cr, 1);
   return FALSE;
 }
-#else
-static gboolean
-color_old_sample_expose (GtkWidget         *da,
-			 GdkEventExpose    *event,
-			 MateColorSelection *colorsel)
-{
-  color_sample_draw_sample (colorsel, 0);
-  return FALSE;
-}
-
-
-static gboolean
-color_cur_sample_expose (GtkWidget         *da,
-			 GdkEventExpose    *event,
-			 MateColorSelection *colorsel)
-{
-  color_sample_draw_sample (colorsel, 1);
-  return FALSE;
-}
-#endif
 
 static void
 color_sample_setup_dnd (MateColorSelection *colorsel, GtkWidget *sample)
@@ -1089,11 +990,7 @@ color_sample_new (MateColorSelection *colorsel)
   
   priv = colorsel->private_data;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   priv->sample_area = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-  priv->sample_area = gtk_hbox_new (FALSE, 0);
-#endif
   priv->old_sample = gtk_drawing_area_new ();
   priv->cur_sample = gtk_drawing_area_new ();
 
@@ -1102,21 +999,12 @@ color_sample_new (MateColorSelection *colorsel)
   gtk_box_pack_start (GTK_BOX (priv->sample_area), priv->cur_sample,
 		      TRUE, TRUE, 0);
   
-#if GTK_CHECK_VERSION (3, 0, 0)
   g_signal_connect (priv->old_sample, "draw",
 		    G_CALLBACK (color_old_sample_draw),
 		    colorsel);
   g_signal_connect (priv->cur_sample, "draw",
 		    G_CALLBACK (color_cur_sample_draw),
 		    colorsel);
-#else
-  g_signal_connect (priv->old_sample, "expose-event",
-		    G_CALLBACK (color_old_sample_expose),
-		    colorsel);
-  g_signal_connect (priv->cur_sample, "expose-event",
-		    G_CALLBACK (color_cur_sample_expose),
-		    colorsel);
-#endif
   
   color_sample_setup_dnd (colorsel, priv->old_sample);
   color_sample_setup_dnd (colorsel, priv->cur_sample);
@@ -1159,16 +1047,9 @@ palette_get_color (GtkWidget *drawing_area, gdouble *color)
 
 static void
 palette_paint (GtkWidget    *drawing_area,
-#if GTK_CHECK_VERSION (3, 0, 0)
                cairo_t      *cr,
-#else
-               GdkRectangle *area,
-#endif
                gpointer      data)
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cairo_t *cr;
-#endif
   gint focus_width;
   GtkAllocation allocation;
     
@@ -1177,16 +1058,8 @@ palette_paint (GtkWidget    *drawing_area,
 
   gtk_widget_get_allocation (drawing_area, &allocation);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cr = gdk_cairo_create (gtk_widget_get_window (drawing_area));
-#endif
-
   gdk_cairo_set_source_color (cr, &gtk_widget_get_style (drawing_area)->bg[GTK_STATE_NORMAL]);
-#if GTK_CHECK_VERSION (3, 0, 0)
   cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
-#else
-  gdk_cairo_rectangle (cr, area);
-#endif
   cairo_fill (cr);
 
   if (gtk_widget_has_focus (drawing_area))
@@ -1199,10 +1072,6 @@ palette_paint (GtkWidget    *drawing_area,
 		       allocation.height - focus_width);
       cairo_stroke (cr);
     }
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  cairo_destroy (cr);
-#endif
 }
 
 static void
@@ -1423,24 +1292,14 @@ palette_set_color (GtkWidget         *drawing_area,
 }
 
 static gboolean
-#if GTK_CHECK_VERSION (3, 0, 0)
 palette_draw (GtkWidget      *drawing_area,
 		cairo_t        *cr,
 		gpointer        data)
-#else
-palette_expose (GtkWidget      *drawing_area,
-		GdkEventExpose *event,
-		gpointer        data)
-#endif
 {
   if (gtk_widget_get_window (drawing_area) == NULL)
     return FALSE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   palette_paint (drawing_area, cr, data);
-#else
-  palette_paint (drawing_area, &(event->area), data);
-#endif
 
   return FALSE;
 }
@@ -1701,13 +1560,8 @@ palette_new (MateColorSelection *colorsel)
                          | GDK_ENTER_NOTIFY_MASK
                          | GDK_LEAVE_NOTIFY_MASK);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   g_signal_connect (retval, "draw",
 		    G_CALLBACK (palette_draw), colorsel);
-#else
-  g_signal_connect (retval, "expose-event",
-		    G_CALLBACK (palette_expose), colorsel);
-#endif
   g_signal_connect (retval, "button-press-event",
 		    G_CALLBACK (palette_press), colorsel);
   g_signal_connect (retval, "button-release-event",
@@ -1755,7 +1609,6 @@ make_picker_cursor (GdkScreen *screen)
 
   if (!cursor)
     {
-#if GTK_CHECK_VERSION (3, 0, 0)
       GdkPixbuf *pixbuf;
 
       pixbuf = gdk_pixbuf_new_from_data (dropper_bits,
@@ -1767,54 +1620,7 @@ make_picker_cursor (GdkScreen *screen)
       cursor = gdk_cursor_new_from_pixbuf (gdk_screen_get_display (screen),
                                            pixbuf,
                                            DROPPER_X_HOT, DROPPER_Y_HOT);
-
       g_object_unref (pixbuf);
-#else
-      GdkColor bg = { 0, 0xffff, 0xffff, 0xffff };
-      GdkColor fg = { 0, 0x0000, 0x0000, 0x0000 };
-      GdkWindow *window;
-      GdkPixmap *pixmap, *mask;
-      cairo_surface_t *image;
-      cairo_t *cr;
-
-      window = gdk_screen_get_root_window (screen);
-      
-
-      pixmap = gdk_pixmap_new (window, DROPPER_WIDTH, DROPPER_HEIGHT, 1);
-
-      cr = gdk_cairo_create (pixmap);
-      cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-      image = cairo_image_surface_create_for_data ((guchar *) dropper_bits,
-                                                   CAIRO_FORMAT_A1,
-                                                   DROPPER_WIDTH,
-                                                   DROPPER_HEIGHT,
-                                                   DROPPER_STRIDE);
-      cairo_set_source_surface (cr, image, 0, 0);
-      cairo_surface_destroy (image);
-      cairo_paint (cr);
-      cairo_destroy (cr);
-      
-
-      mask = gdk_pixmap_new (window, DROPPER_WIDTH, DROPPER_HEIGHT, 1);
-
-      cr = gdk_cairo_create (mask);
-      cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-      image = cairo_image_surface_create_for_data ((guchar *) dropper_mask,
-                                                   CAIRO_FORMAT_A1,
-                                                   DROPPER_WIDTH,
-                                                   DROPPER_HEIGHT,
-                                                   DROPPER_STRIDE);
-      cairo_set_source_surface (cr, image, 0, 0);
-      cairo_surface_destroy (image);
-      cairo_paint (cr);
-      cairo_destroy (cr);
-      
-      cursor = gdk_cursor_new_from_pixmap (pixmap, mask, &fg, &bg,
-					   DROPPER_X_HOT, DROPPER_Y_HOT);
-      
-      g_object_unref (pixmap);
-      g_object_unref (mask);
-#endif
     }
       
   return cursor;
@@ -1835,16 +1641,9 @@ grab_color_at_mouse (GdkScreen *screen,
   
   priv = colorsel->private_data;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   pixbuf = gdk_pixbuf_get_from_window (root_window,
                                        x_root, y_root,
                                        1, 1);
-#else
-  pixbuf = gdk_pixbuf_get_from_drawable (NULL, root_window, NULL,
-                                         x_root, y_root,
-                                         0, 0,
-                                         1, 1);
-#endif
   if (!pixbuf)
     {
       gint x, y;
@@ -1852,16 +1651,9 @@ grab_color_at_mouse (GdkScreen *screen,
       GdkWindow *window = gdk_display_get_window_at_pointer (display, &x, &y);
       if (!window)
 	return;
-#if GTK_CHECK_VERSION (3, 0, 0)
       pixbuf = gdk_pixbuf_get_from_window (window,
                                            x, y,
                                            1, 1);
-#else
-      pixbuf = gdk_pixbuf_get_from_drawable (NULL, window, NULL,
-                                             x, y,
-                                             0, 0,
-                                             1, 1);
-#endif
       if (!pixbuf)
 	return;
     }
@@ -2086,11 +1878,7 @@ get_screen_color (GtkWidget *button)
 				  NULL,
 				  picker_cursor,
 				  time);
-#if GTK_CHECK_VERSION (3, 0, 0)
   g_object_unref (picker_cursor);
-#else
-  gdk_cursor_unref (picker_cursor);
-#endif
   
   if (grab_status != GDK_GRAB_SUCCESS)
     {
@@ -2259,7 +2047,7 @@ static void
 make_label_spinbutton (MateColorSelection *colorsel,
 		       GtkWidget        **spinbutton,
 		       gchar             *text,
-		       GtkWidget         *table,
+		       GtkWidget         *grid,
 		       gint               i,
 		       gint               j,
 		       gint               channel_type,
@@ -2297,13 +2085,13 @@ make_label_spinbutton (MateColorSelection *colorsel,
 #else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 #endif
-  gtk_table_attach_defaults (GTK_TABLE (table), label, i, i+1, j, j+1);
-  gtk_table_attach_defaults (GTK_TABLE (table), *spinbutton, i+1, i+2, j, j+1);
+  gtk_grid_attach (GTK_GRID (grid), label, i, j, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), *spinbutton, i+1, j, 1, 1);
 }
 
 static void
 make_palette_frame (MateColorSelection *colorsel,
-		    GtkWidget         *table,
+		    GtkWidget         *grid,
 		    gint               i,
 		    gint               j)
 {
@@ -2316,7 +2104,8 @@ make_palette_frame (MateColorSelection *colorsel,
   priv->custom_palette[i][j] = palette_new (colorsel);
   gtk_widget_set_size_request (priv->custom_palette[i][j], CUSTOM_PALETTE_ENTRY_WIDTH, CUSTOM_PALETTE_ENTRY_HEIGHT);
   gtk_container_add (GTK_CONTAINER (frame), priv->custom_palette[i][j]);
-  gtk_table_attach_defaults (GTK_TABLE (table), frame, i, i+1, j, j+1);
+  gtk_widget_set_hexpand (frame, TRUE);
+  gtk_grid_attach (GTK_GRID (grid), frame, i, j, 1, 1);
 }
 
 /* Set the palette entry [x][y] to be the currently selected one. */
