@@ -25,7 +25,10 @@
 #ifndef __MATE_DESKTOP_H__
 #define __MATE_DESKTOP_H__
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <glib.h>
 
 G_BEGIN_DECLS
