@@ -499,12 +499,7 @@ fill_out_screen_info (Display *xdisplay,
     info->primary = None;
     gdk_error_trap_push ();
     info->primary = XRRGetOutputPrimary (xdisplay, xroot);
-#if GTK_CHECK_VERSION (3, 0, 0)
-	gdk_error_trap_pop_ignored ();
-#else
-	gdk_flush ();
-	gdk_error_trap_pop (); /* ignore error */
-#endif
+    gdk_error_trap_pop_ignored ();
 
     return TRUE;
 #else
@@ -851,12 +846,7 @@ mate_rr_screen_set_size (MateRRScreen *screen,
     gdk_error_trap_push ();
     XRRSetScreenSize (screen->priv->xdisplay, screen->priv->xroot,
 		      width, height, mm_width, mm_height);
-  #if GTK_CHECK_VERSION (3, 0, 0)
     gdk_error_trap_pop_ignored ();
-  #else
-    gdk_flush ();
-    gdk_error_trap_pop (); /* ignore error */
-  #endif
 #endif
 }
 
